#!/usr/bin/env rexx
/* This routine will be called from the Rexx code defined in the Button element in
   with the fx:id="button" the "onAction" attribute in the FXML Button definition */

::requires 'UNO.CLS'

::routine buttonClicked public
  slotDir=arg(arg())  -- last argument is the slotDir argument from BSF4ooRexx
  say .dateTime~new": arrived in routine 'buttonClicked' ..."

  /* Fetch the text field contents from the GUI */
  /* @get(idTextField1) */
  /* @get(idTextField2) */
  /* @get(idTextField3) */
  textField1Text = idTextField1~getText
  textField2Text = idTextField2~getText
  textField3Text = idTextField3~getText

  /* Initialize the UNO bridge and open a new Writer document */
  xDesktop = UNO.createDesktop()       /* get the OOo XDesktop interface to the service object */
  xComponentLoader = xDesktop~XComponentLoader /* get XComponentLoader interface */
  
  url = "private:factory/swriter"
  writerComponent = xComponentLoader~loadComponentFromURL(url, "_blank", 0, .UNO~noProps)
  
  /* Get the text object (a text cursor) */
  xText = writerComponent~XTextDocument~getText
  
  /* Insert text from text fields */
  xText~setString("Habit 1: " || textField1Text || "0a"x)
  xText~setString(xText~getString || "Habit 2: " || textField2Text || "0a"x)
  xText~setString(xText~getString || "Habit 3: " || textField3Text || "0a"x)
  
  /* Inform user about what is going to happen, then dispose the writer document */
  .bsf.dialog~messageBox("This writer document will now close.", "Closing Dialog", "info")
  writerComponent~XCloseable~close(.true)   /* force closing of the window document, no questions asked ... */

  say 'Text from text fields successfully written to LibreOffice Writer document and document closed.'
  return



::routine dumpAllBindings
    use strict arg title, scriptContext
    /* show the currently defined attributes in the default ScriptContext's scopes   */
    say  title 'at' pp(.dateTime~new)':'
    say
    say "getting all attributes from all ScriptContext's scopes..."
    allScopes=scriptContext~getScopes  -- there may be any number of scopes

    do scope over allScopes      -- show Bindings for each scope
        say "ScriptContext scope:" pp(scope) getScopeTitle(scope)
        bin=scriptContext~getBindings(scope)
        if bin=.nil then iterate -- inexistent scope
        minWidth=31              -- minimum width for key column
        keys=bin~keySet          -- get kay values
        it=keys~makearray        -- get the keys as a Rexx array
        do key over it~sortWith(.CaselessComparator~new) -- sort keys caselessly
           val=bin~get(key)      -- fetch the key's value
           str=" " pp(key)~left(max(minWidth,key~length+2),".")":" pp(val)
           if key="location" then str=str "~toString="pp(val~toString)
           say str
        end
        say copies("-",86)
    end
    say copies("=",86)
    return

getScopeTitle: procedure
   parse arg scopeNumber
   if      scopeNumber=100 then return "[ENGINE_SCOPE]"
   else if scopeNumber=200 then return "[GLOBAL_SCOPE]"
   return ""
